.. _swh-indexer:

Software Heritage - Indexer
===========================

Tools and workers used to mine the content of the archive and extract derived
information from archive source code artifacts.


.. toctree::
   :maxdepth: 1
   :caption: Contents:

   README.md
   dev-info.rst
   metadata-workflow.rst


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   /apidoc/swh.indexer
